@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::InitTarget;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,7 +53,7 @@ Bencher::Scenario::LogGer::InitTarget - Benchmark init_target()
 
 =head1 VERSION
 
-This document describes version 0.013 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.014 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/5fZO3OAq1x'); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/ljRni0BSz4'); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -119,7 +119,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/5fZO3OAq1x'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/ljRni0BSz4'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -127,7 +127,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/5fZO3OAq1x'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/ljRni0BSz4'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -140,17 +140,17 @@ Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 Benchmark with default options (C<< bencher -m LogGer::InitTarget >>):
 
  #table1#
- +----------------------------------------------------+-----------+-----------+------------+---------+---------+
- | participant                                        | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +----------------------------------------------------+-----------+-----------+------------+---------+---------+
- | with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       360 |       1    | 0.0015  |       7 |
- | default                                            |      2.8  |       350 |       1    | 0.0005  |       7 |
- | with LGO:Composite (Screen+File)                   |      2.92 |       343 |       1.05 | 0.00032 |       7 |
- | with LGO:Composite (Screen)                        |      4    |       250 |       1.4  | 0.00042 |       7 |
- | with LGO:File                                      |      5.32 |       188 |       1.92 | 0.00016 |       7 |
- | with LGO:Screen                                    |      7.4  |       130 |       2.7  | 0.0003  |       7 |
- | with LGO:Composite (0 outputs)                     |      7.4  |       130 |       2.7  | 0.00015 |       7 |
- +----------------------------------------------------+-----------+-----------+------------+---------+---------+
+ +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                                        | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       360 |       1    |   0.0012  |       7 |
+ | default                                            |      2.85 |       350 |       1.03 | 8.8e-05   |       7 |
+ | with LGO:Composite (Screen+File)                   |      2.99 |       335 |       1.07 |   0.0002  |       8 |
+ | with LGO:Composite (Screen)                        |      4.02 |       249 |       1.45 |   0.00012 |       7 |
+ | with LGO:File                                      |      5.3  |       190 |       1.9  |   0.00023 |       7 |
+ | with LGO:Composite (0 outputs)                     |      7.42 |       135 |       2.67 |   0.00011 |       7 |
+ | with LGO:Screen                                    |      7.44 |       134 |       2.67 | 2.5e-05   |       7 |
+ +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
