@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::LayoutStartup;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ Bencher::Scenario::LogGer::LayoutStartup
 
 =head1 VERSION
 
-This document describes version 0.013 of Bencher::Scenario::LogGer::LayoutStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.014 of Bencher::Scenario::LogGer::LayoutStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -121,11 +121,11 @@ Benchmark with default options (C<< bencher -m LogGer::LayoutStartup >>):
  +--------------+-----------+-----------+------------+---------+---------+
  | participant  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +--------------+-----------+-----------+------------+---------+---------+
- | load-YAML    |        68 |      15   |        1   |   3e-05 |      20 |
- | load-JSON    |        69 |      14   |        1   | 3.4e-05 |      20 |
- | load-LTSV    |        71 |      14   |        1   | 3.8e-05 |      20 |
- | load-Pattern |        71 |      14   |        1   | 1.9e-05 |      20 |
- | baseline     |       180 |       5.6 |        2.6 | 2.5e-05 |      21 |
+ | load-YAML    |        67 |      15   |        1   | 5.8e-05 |      21 |
+ | load-LTSV    |        70 |      14   |        1   |   6e-05 |      20 |
+ | load-JSON    |        71 |      14   |        1.1 | 3.2e-05 |      20 |
+ | load-Pattern |        71 |      14   |        1.1 | 5.5e-05 |      20 |
+ | baseline     |       190 |       5.3 |        2.8 | 2.7e-05 |      20 |
  +--------------+-----------+-----------+------------+---------+---------+
 
 
@@ -135,11 +135,11 @@ Benchmark module startup overhead (C<< bencher -m LogGer::LayoutStartup --module
  +---------------------------+-----------+------------------------+------------+---------+---------+
  | participant               | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Layout::YAML    |      14   |                    9.3 |          1 | 3.2e-05 |      20 |
- | Log::ger::Layout::JSON    |      14   |                    9.3 |          1 | 2.1e-05 |      20 |
- | Log::ger::Layout::LTSV    |      14   |                    9.3 |          1 | 3.1e-05 |      20 |
- | Log::ger::Layout::Pattern |      13   |                    8.3 |          1 | 1.4e-05 |      20 |
- | perl -e1 (baseline)       |       4.7 |                    0   |          3 | 5.8e-06 |      22 |
+ | Log::ger::Layout::JSON    |        14 |                      9 |          1 | 8.8e-05 |      20 |
+ | Log::ger::Layout::YAML    |        14 |                      9 |          1 | 4.4e-05 |      20 |
+ | Log::ger::Layout::LTSV    |        14 |                      9 |          1 | 6.1e-05 |      20 |
+ | Log::ger::Layout::Pattern |        14 |                      9 |          1 | 2.4e-05 |      21 |
+ | perl -e1 (baseline)       |         5 |                      0 |          3 | 7.2e-05 |      20 |
  +---------------------------+-----------+------------------------+------------+---------+---------+
 
 
