@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NumericLevel;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use 5.010001;
 use strict;
@@ -35,7 +35,7 @@ Bencher::Scenario::LogGer::NumericLevel - Benchmark numeric_level()
 
 =head1 VERSION
 
-This document describes version 0.013 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.014 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Util> 0.023
+L<Log::ger::Util> 0.025
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -93,8 +93,8 @@ Benchmark with default options (C<< bencher -m LogGer::NumericLevel >>):
  +---------+-----------+-----------+------------+---------+---------+
  | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | warn    |   2060000 |       484 |        1   | 2.5e-10 |      25 |
- | 10      |   2200000 |       450 |        1.1 | 1.6e-09 |      21 |
+ | warn    |   2110000 |       475 |       1    | 1.5e-10 |      20 |
+ | 10      |   2500000 |       401 |       1.18 | 2.6e-10 |      20 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
@@ -104,8 +104,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::NumericLevel --module-
  +---------------------+-----------+------------------------+------------+---------+---------+
  | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      |        12 |                      6 |          1 | 6.4e-05 |      24 |
- | perl -e1 (baseline) |         6 |                      0 |          2 | 9.6e-05 |      20 |
+ | Log::ger::Util      |      12   |                    6.4 |        1   | 5.1e-05 |      20 |
+ | perl -e1 (baseline) |       5.6 |                    0   |        2.1 | 3.2e-05 |      20 |
  +---------------------+-----------+------------------------+------------+---------+---------+
 
 
