@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Overhead;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,6 +25,7 @@ our $scenario = {
         'Log::Log4perl' => {version=>'0'},
         'Log::Log4perl::Tiny' => {version=>'0'},
         'Log::Dispatchouli' => {version=>'0'},
+        'Mojo::Log' => {version=>'0'},
     },
     code_startup => 1,
     participants => [
@@ -55,6 +56,9 @@ our $scenario = {
         {code_template=>'use Log::ger::Output::Screen;', tags=>['output']},
         {code_template=>'use Log::ger::Output::Composite;', tags=>['output']},
 
+        {code_template=>'use Mojo::Log;'},
+        {code_template=>'use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")'},
+
         # TODO: Lg + Composite (2 outputs)
         # TODO: Lg + Composite (2 outputs + pattern layouts)
         # TODO: Log::Any + Screen
@@ -77,7 +81,7 @@ Bencher::Scenario::LogGer::Overhead - Measure startup overhead of various codes
 
 =head1 VERSION
 
-This document describes version 0.013 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.014 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -109,13 +113,15 @@ L<Log::Log4perl> 1.49
 
 L<Log::Log4perl::Tiny> 1.4.0
 
-L<Log::ger> 0.023
+L<Log::ger> 0.025
 
 L<Log::ger::App> 0.009
 
 L<Log::ger::Layout::Pattern> 0.001
 
-L<Log::ger::Output> 0.023
+L<Log::ger::Output> 0.025
+
+L<Mojo::Log>
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -273,6 +279,22 @@ Code template:
 
 
 
+=item * use Mojo::Log; (perl_code)
+
+Code template:
+
+ use Mojo::Log;
+
+
+
+=item * use Mojo::Log; my $log=Mojo::Log->new(level=>"warn") (perl_code)
+
+Code template:
+
+ use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -285,25 +307,27 @@ Benchmark with default options (C<< bencher -m LogGer::Overhead >>):
  +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
  | participant                                                      | time (ms) | code_overhead_time (ms) | vs_slowest |  errors   | samples |
  +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
- | use Log::Dispatchouli;                                           |     103   |      97.4               |       1    | 8.2e-05   |      20 |
- | use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu |     100   |      94.4               |       1    |   0.00011 |      20 |
- | use Log::Dispatch;                                               |      95.2 |      89.6               |       1.08 | 7.4e-05   |      20 |
- | use Log::Contextual qw(:log);                                    |      77   |      71.4               |       1.3  |   0.00015 |      20 |
- | use Log::Log4perl;                                               |      37.4 |      31.8               |       2.76 | 2.6e-05   |      20 |
- | use Log::ger::App; use Log::ger;                                 |      20   |      14.4               |       4    |   0.00025 |      20 |
- | use Log::Log4perl::Tiny;                                         |      21   |      15.4               |       4.9  | 3.1e-05   |      20 |
- | use Log::ger::App;                                               |      20   |      14.4               |       6    |   0.0002  |      20 |
- | use Log::ger::Like::Log4perl;                                    |      16   |      10.4               |       6.3  |   4e-05   |      20 |
- | use Log::Any q($log);                                            |      15   |       9.4               |       6.9  | 9.4e-05   |      20 |
- | use Log::Any;                                                    |      14   |       8.4               |       7.2  | 3.3e-05   |      21 |
- | use Log::ger::Output::Screen;                                    |      13   |       7.4               |       8.3  |   0.00012 |      20 |
- | use Log::ger::Output::Composite;                                 |      10   |       4.4               |      10    |   0.00015 |      20 |
- | use Log::ger::Plugin::OptAway; use Log::ger;                     |       8.8 |       3.2               |      12    | 2.8e-05   |      22 |
- | use Log::ger ();                                                 |       6.5 |       0.9               |      16    |   3e-05   |      20 |
- | use Log::ger; Log::ger->get_logger;                              |       6   |       0.4               |      20    | 7.4e-05   |      20 |
- | use Log::ger::Like::LogAny;                                      |       6.4 |       0.800000000000001 |      16    | 1.5e-05   |      21 |
- | use Log::ger;                                                    |       6.3 |       0.7               |      16    | 3.6e-05   |      20 |
- | perl -e1 (baseline)                                              |       5.6 |       0                 |      18    | 3.6e-05   |      20 |
+ | use Log::Dispatchouli;                                           |     110   |                   104   |        1   |   0.00018 |      20 |
+ | use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu |     100   |                    94   |        1   |   0.00014 |      20 |
+ | use Log::Dispatch;                                               |     100   |                    94   |        1.1 |   0.00048 |      20 |
+ | use Mojo::Log;                                                   |      94   |                    88   |        1.1 |   0.00024 |      20 |
+ | use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")             |      92   |                    86   |        1.2 |   0.00019 |      20 |
+ | use Log::Contextual qw(:log);                                    |      80   |                    74   |        1.3 |   0.00014 |      20 |
+ | use Log::Log4perl;                                               |      40   |                    34   |        2.7 |   0.00022 |      20 |
+ | use Log::ger::App; use Log::ger;                                 |      23   |                    17   |        4.6 | 6.1e-05   |      20 |
+ | use Log::Log4perl::Tiny;                                         |      23   |                    17   |        4.7 |   0.00012 |      20 |
+ | use Log::ger::App;                                               |      17   |                    11   |        6.4 | 5.5e-05   |      20 |
+ | use Log::ger::Like::Log4perl;                                    |      16   |                    10   |        6.4 | 3.3e-05   |      20 |
+ | use Log::Any q($log);                                            |      15   |                     9   |        6.9 | 4.5e-05   |      20 |
+ | use Log::Any;                                                    |      14   |                     8   |        7.4 | 4.7e-05   |      20 |
+ | use Log::ger::Output::Screen;                                    |      12   |                     6   |        8.7 | 3.6e-05   |      21 |
+ | use Log::ger::Output::Composite;                                 |       9.1 |                     3.1 |       12   | 3.1e-05   |      20 |
+ | use Log::ger::Plugin::OptAway; use Log::ger;                     |       9   |                     3   |       12   | 4.5e-05   |      21 |
+ | use Log::ger::Like::LogAny;                                      |       7   |                     1   |       15   |   4e-05   |      20 |
+ | use Log::ger; Log::ger->get_logger;                              |       6.6 |                     0.6 |       16   | 2.3e-05   |      20 |
+ | use Log::ger;                                                    |       6.6 |                     0.6 |       16   | 3.9e-05   |      21 |
+ | use Log::ger ();                                                 |       6.5 |                     0.5 |       16   | 5.1e-05   |      20 |
+ | perl -e1 (baseline)                                              |       6   |                     0   |       18   | 5.5e-05   |      20 |
  +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
 
 
