@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::StringLevel;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ Bencher::Scenario::LogGer::StringLevel - Benchmark string_level()
 
 =head1 VERSION
 
-This document describes version 0.013 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.014 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Util> 0.023
+L<Log::ger::Util> 0.025
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -96,8 +96,8 @@ Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
  +---------+-----------+-----------+------------+---------+---------+
  | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | 10      |    820000 |      1200 |        1   | 1.9e-09 |      25 |
- | warn    |   3710000 |       270 |        4.5 | 4.6e-11 |      20 |
+ | 10      |    800000 |      1300 |       1    | 1.7e-09 |      20 |
+ | warn    |   3960000 |       253 |       4.95 | 5.7e-11 |      20 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
@@ -107,8 +107,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::StringLevel --module-s
  +---------------------+-----------+------------------------+------------+---------+---------+
  | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      |        11 |                      6 |          1 | 5.3e-05 |      20 |
- | perl -e1 (baseline) |         5 |                      0 |          2 | 6.1e-05 |      21 |
+ | Log::ger::Util      |        12 |                      6 |          1 | 5.5e-05 |      20 |
+ | perl -e1 (baseline) |         6 |                      0 |          2 |   7e-05 |      21 |
  +---------------------+-----------+------------------------+------------+---------+---------+
 
 
