@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::InitTarget;
 
-our $VERSION = 0.013; # VERSION
+our $VERSION = 0.014; # VERSION
 
 our $results = [
   [
@@ -8,7 +8,7 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0015,
+        errors => 0.0012,
         participant => "with LGO:Composite (Screen+File & pattern layouts)",
         rate => 2.8,
         samples => 7,
@@ -16,52 +16,52 @@ our $results = [
         vs_slowest => 1,
       },
       {
-        errors => 0.0005,
+        errors => 8.8e-05,
         participant => "default",
-        rate => 2.8,
+        rate => 2.85,
         samples => 7,
         time => 350,
-        vs_slowest => 1,
+        vs_slowest => 1.03,
       },
       {
-        errors => 0.00032,
+        errors => 0.0002,
         participant => "with LGO:Composite (Screen+File)",
-        rate => 2.92,
-        samples => 7,
-        time => 343,
-        vs_slowest => 1.05,
+        rate => 2.99,
+        samples => 8,
+        time => 335,
+        vs_slowest => 1.07,
       },
       {
-        errors => 0.00042,
+        errors => 0.00012,
         participant => "with LGO:Composite (Screen)",
-        rate => 4,
+        rate => 4.02,
         samples => 7,
-        time => 250,
-        vs_slowest => 1.4,
+        time => 249,
+        vs_slowest => 1.45,
       },
       {
-        errors => 0.00016,
+        errors => 0.00023,
         participant => "with LGO:File",
-        rate => 5.32,
+        rate => 5.3,
         samples => 7,
-        time => 188,
-        vs_slowest => 1.92,
+        time => 190,
+        vs_slowest => 1.9,
       },
       {
-        errors => 0.0003,
-        participant => "with LGO:Screen",
-        rate => 7.4,
-        samples => 7,
-        time => 130,
-        vs_slowest => 2.7,
-      },
-      {
-        errors => 0.00015,
+        errors => 0.00011,
         participant => "with LGO:Composite (0 outputs)",
-        rate => 7.4,
+        rate => 7.42,
         samples => 7,
-        time => 130,
-        vs_slowest => 2.7,
+        time => 135,
+        vs_slowest => 2.67,
+      },
+      {
+        errors => 2.5e-05,
+        participant => "with LGO:Screen",
+        rate => 7.44,
+        samples => 7,
+        time => 134,
+        vs_slowest => 2.67,
       },
     ],
     {
@@ -165,7 +165,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3222.607,
+                                              speed                        => 3250.988,
                                               stepping                     => 7,
                                             },
                                             {
@@ -260,7 +260,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3303.399,
+                                              speed                        => "3236.230",
                                               stepping                     => 7,
                                             },
                                             {
@@ -355,7 +355,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3264.801,
+                                              speed                        => 3291.857,
                                               stepping                     => 7,
                                             },
                                             {
@@ -450,11 +450,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3289.019,
+                                              speed                        => "3248.150",
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 15.5287089347839,
+      "func.elapsed_time"              => 16.6875970363617,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.041,
@@ -495,9 +495,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1499942633,
       "func.scenario_module_sha1sum"   => "04369046d22a6d1e2ce7ae2fc07be5e54ddf2e04",
       "func.scenario_module_sha256sum" => "733fb6fa020e5d8133f3addf99e97085c8878254367f5d714a603650c8820b2f",
-      "func.time_end"                  => 1545303580.45636,
+      "func.time_end"                  => 1545319787.14073,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1545303564.92765,
+      "func.time_start"                => 1545319770.45314,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
