@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.013; # VERSION
+our $VERSION = 0.014; # VERSION
 
 our $results = [
   [
@@ -8,55 +8,55 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0027,
+        errors => 0.0039,
         participant => "Log::Dispatch::Null-100k_debug",
-        rate => 0.6,
+        rate => 0.59,
         samples => 6,
         time => 1.7,
         vs_slowest => 1,
       },
       {
-        errors => 0.0018,
+        errors => 0.0046,
         participant => "Log::Contextual+Log4perl-100k_trace",
         rate => 1.5,
         samples => 6,
+        time => 0.66,
+        vs_slowest => 2.6,
+      },
+      {
+        errors => 0.0032,
+        participant => "Log::Contextual+SimpleLogger-100k_trace",
+        rate => 1.5,
+        samples => 6,
         time => 0.65,
         vs_slowest => 2.6,
       },
       {
-        errors => 0.0035,
-        participant => "Log::Contextual+SimpleLogger-100k_trace",
-        rate => 1.6,
+        errors => 0.0014,
+        participant => "Mojo::Log-100k_debug",
+        rate => 3.1,
         samples => 6,
-        time => 0.64,
-        vs_slowest => 2.6,
+        time => 0.32,
+        vs_slowest => 5.3,
       },
       {
-        errors => 0.00084,
+        errors => 0.0023,
         participant => "Log::Dispatchouli-100k_debug",
-        rate => 4.7,
-        samples => 7,
-        time => 0.21,
-        vs_slowest => 7.9,
+        rate => 5,
+        samples => 6,
+        time => 0.2,
+        vs_slowest => 8,
       },
       {
-        errors => 0.00037,
+        errors => 0.00044,
         participant => "Log::Log4perl::Tiny-100k_trace",
         rate => 7.3,
-        samples => 8,
+        samples => 6,
         time => 0.14,
-        vs_slowest => 12,
+        vs_slowest => 13,
       },
       {
-        errors => 0.00018,
-        participant => "Log::Any-null_adapter-100k_log_trace",
-        rate => 12,
-        samples => 8,
-        time => 0.082,
-        vs_slowest => 21,
-      },
-      {
-        errors => 0.00093,
+        errors => 0.00087,
         participant => "Log::Fast-100k_is_debug",
         rate => 10,
         samples => 6,
@@ -64,83 +64,91 @@ our $results = [
         vs_slowest => 20,
       },
       {
-        errors => 2.4e-05,
+        errors => 0.00025,
+        participant => "Log::Any-null_adapter-100k_log_trace",
+        rate => 13,
+        samples => 7,
+        time => 0.079,
+        vs_slowest => 22,
+      },
+      {
+        errors => 0.00012,
         participant => "Log::Log4perl-easy-100k_trace",
-        rate => 15.1,
+        rate => 14,
         samples => 6,
-        time => 0.0661,
-        vs_slowest => 25.4,
+        time => 0.069,
+        vs_slowest => 25,
       },
       {
-        errors => 0.00018,
+        errors => 0.00097,
         participant => "Log::Any-no_adapter-100k_is_trace",
-        rate => 17,
+        rate => 20,
         samples => 6,
-        time => 0.057,
-        vs_slowest => 29,
+        time => 0.06,
+        vs_slowest => 30,
       },
       {
-        errors => 7.5e-05,
+        errors => 0.0007,
         participant => "Log::Any-null_adapter-100k_is_trace",
-        rate => 19,
-        samples => 6,
-        time => 0.054,
-        vs_slowest => 31,
-      },
-      {
-        errors => 0.0008,
-        participant => "Log::Fast-100k_DEBUG",
         rate => 20,
         samples => 9,
+        time => 0.06,
+        vs_slowest => 30,
+      },
+      {
+        errors => 0.00071,
+        participant => "Log::Fast-100k_DEBUG",
+        rate => 20,
+        samples => 6,
         time => 0.05,
         vs_slowest => 40,
       },
       {
-        errors => 0.00027,
+        errors => 0.00037,
         participant => "Log::Any-no_adapter-100k_log_trace",
-        rate => 32,
-        samples => 7,
-        time => 0.031,
-        vs_slowest => 53,
+        rate => 30,
+        samples => 6,
+        time => 0.03,
+        vs_slowest => 60,
       },
       {
-        errors => 7.6e-05,
+        errors => 4e-06,
         participant => "Log::ger+LGP:OptAway-100k_log_trace",
-        rate => 41,
-        samples => 8,
-        time => 0.024,
-        vs_slowest => 69,
+        rate => 44.8,
+        samples => 6,
+        time => 0.0223,
+        vs_slowest => 76.5,
       },
       {
-        errors => 0.00044,
-        participant => "Log::ger+LGP:MutilevelLog-100k_log_trace",
-        rate => 40,
-        samples => 7,
-        time => 0.02,
-        vs_slowest => 70,
-      },
-      {
-        errors => 0.00017,
+        errors => 9.8e-05,
         participant => "Log::ger+LGP:MutilevelLog-100k_log_6",
-        rate => 44,
+        rate => 45,
+        samples => 7,
+        time => 0.022,
+        vs_slowest => 77,
+      },
+      {
+        errors => 0.00016,
+        participant => "Log::ger+LGP:MutilevelLog-100k_log_trace",
+        rate => 46,
         samples => 6,
         time => 0.022,
-        vs_slowest => 75,
+        vs_slowest => 79,
       },
       {
-        errors => 0.00014,
+        errors => 7.9e-05,
         participant => "Log::ger-100k_log_is_trace",
-        rate => 61,
-        samples => 7,
-        time => 0.016,
+        rate => 59,
+        samples => 6,
+        time => 0.017,
         vs_slowest => 100,
       },
       {
-        errors => 8.9e-05,
+        errors => 1.7e-05,
         participant => "Log::ger-100k_log_trace",
-        rate => 61,
+        rate => 59,
         samples => 6,
-        time => 0.016,
+        time => 0.017,
         vs_slowest => 100,
       },
     ],
@@ -245,7 +253,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3218.634,
+                                              speed                        => 3229.418,
                                               stepping                     => 7,
                                             },
                                             {
@@ -340,7 +348,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "3221.850",
+                                              speed                        => 3212.957,
                                               stepping                     => 7,
                                             },
                                             {
@@ -435,7 +443,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3210.308,
+                                              speed                        => 3355.621,
                                               stepping                     => 7,
                                             },
                                             {
@@ -530,11 +538,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3201.794,
+                                              speed                        => 3281.829,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 31.769749879837,
+      "func.elapsed_time"              => 32.1005539894104,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                           => 1.041,
@@ -548,16 +556,17 @@ our $results = [
                                             "Log::Dispatch::Null"                   => 2.65,
                                             "Log::Dispatchouli"                     => 2.015,
                                             "Log::Fast"                             => "v2.0.0",
-                                            "Log::ger"                              => 0.023,
-                                            "Log::ger::Plugin::MultilevelLog"       => 0.023,
+                                            "Log::ger"                              => 0.025,
+                                            "Log::ger::Plugin::MultilevelLog"       => 0.025,
                                             "Log::ger::Plugin::OptAway"             => 0.006,
                                             "Log::Log4perl"                         => 1.49,
                                             "Log::Log4perl::Tiny"                   => "1.4.0",
+                                            "Mojo::Log"                             => undef,
                                             "perl"                                  => "v5.26.0",
                                             "Sys::Info"                             => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 16]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 17]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sonya",
@@ -583,13 +592,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "2545aa76918d20d72bc07f68ab9e751f",
-      "func.scenario_module_mtime"     => 1545303314,
-      "func.scenario_module_sha1sum"   => "e8e8d813e5d3cb164adf45da30990b691a5b10eb",
-      "func.scenario_module_sha256sum" => "6fc798b7c6de437769f1c479d30b2445af82124cb7300cdd50119a891eb1db87",
-      "func.time_end"                  => 1545303619.95853,
+      "func.scenario_module_md5sum"    => "b5cf0486576cda4b6dbca9546f27f7ee",
+      "func.scenario_module_mtime"     => 1545319588,
+      "func.scenario_module_sha1sum"   => "472fe6ab46629db97bec4f9bf6e3cf79e7bdb47a",
+      "func.scenario_module_sha256sum" => "7bdb9b1fe53b55024a17b18b04d8c10548137baa4d87ea4cf1568da901e03b80",
+      "func.time_end"                  => 1545319827.48435,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1545303588.18878,
+      "func.time_start"                => 1545319795.38379,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s"],
       "table.fields"                   => [
