@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Overhead;
 
-our $VERSION = 0.013; # VERSION
+our $VERSION = 0.014; # VERSION
 
 our $results = [
   [
@@ -8,155 +8,171 @@ our $results = [
     "OK",
     [
       {
-        code_overhead_time => 97.4,
-        errors => 8.2e-05,
+        code_overhead_time => 104,
+        errors => 0.00018,
         participant => "use Log::Dispatchouli;",
         samples => 20,
-        time => 103,
+        time => 110,
         vs_slowest => 1,
       },
       {
-        code_overhead_time => 94.4,
-        errors => 0.00011,
+        code_overhead_time => 94,
+        errors => 0.00014,
         participant => "use Log::Dispatch; my \$null = Log::Dispatch->new(outputs=>[ [\"Nu",
         samples => 20,
         time => 100,
         vs_slowest => 1,
       },
       {
-        code_overhead_time => 89.6,
-        errors => 7.4e-05,
+        code_overhead_time => 94,
+        errors => 0.00048,
         participant => "use Log::Dispatch;",
         samples => 20,
-        time => 95.2,
-        vs_slowest => 1.08,
+        time => 100,
+        vs_slowest => 1.1,
       },
       {
-        code_overhead_time => 71.4,
-        errors => 0.00015,
+        code_overhead_time => 88,
+        errors => 0.00024,
+        participant => "use Mojo::Log;",
+        samples => 20,
+        time => 94,
+        vs_slowest => 1.1,
+      },
+      {
+        code_overhead_time => 86,
+        errors => 0.00019,
+        participant => "use Mojo::Log; my \$log=Mojo::Log->new(level=>\"warn\")",
+        samples => 20,
+        time => 92,
+        vs_slowest => 1.2,
+      },
+      {
+        code_overhead_time => 74,
+        errors => 0.00014,
         participant => "use Log::Contextual qw(:log);",
         samples => 20,
-        time => 77,
+        time => 80,
         vs_slowest => 1.3,
       },
       {
-        code_overhead_time => 31.8,
-        errors => 2.6e-05,
+        code_overhead_time => 34,
+        errors => 0.00022,
         participant => "use Log::Log4perl;",
         samples => 20,
-        time => 37.4,
-        vs_slowest => 2.76,
+        time => 40,
+        vs_slowest => 2.7,
       },
       {
-        code_overhead_time => 14.4,
-        errors => 0.00025,
+        code_overhead_time => 17,
+        errors => 6.1e-05,
         participant => "use Log::ger::App; use Log::ger;",
         samples => 20,
-        time => 20,
-        vs_slowest => 4,
+        time => 23,
+        vs_slowest => 4.6,
       },
       {
-        code_overhead_time => 15.4,
-        errors => 3.1e-05,
+        code_overhead_time => 17,
+        errors => 0.00012,
         participant => "use Log::Log4perl::Tiny;",
         samples => 20,
-        time => 21,
-        vs_slowest => 4.9,
+        time => 23,
+        vs_slowest => 4.7,
       },
       {
-        code_overhead_time => 14.4,
-        errors => 0.0002,
+        code_overhead_time => 11,
+        errors => 5.5e-05,
         participant => "use Log::ger::App;",
         samples => 20,
-        time => 20,
-        vs_slowest => 6,
+        time => 17,
+        vs_slowest => 6.4,
       },
       {
-        code_overhead_time => 10.4,
-        errors => 4e-05,
+        code_overhead_time => 10,
+        errors => 3.3e-05,
         participant => "use Log::ger::Like::Log4perl;",
         samples => 20,
         time => 16,
-        vs_slowest => 6.3,
+        vs_slowest => 6.4,
       },
       {
-        code_overhead_time => 9.4,
-        errors => 9.4e-05,
+        code_overhead_time => 9,
+        errors => 4.5e-05,
         participant => "use Log::Any q(\$log);",
         samples => 20,
         time => 15,
         vs_slowest => 6.9,
       },
       {
-        code_overhead_time => 8.4,
-        errors => 3.3e-05,
+        code_overhead_time => 8,
+        errors => 4.7e-05,
         participant => "use Log::Any;",
-        samples => 21,
-        time => 14,
-        vs_slowest => 7.2,
-      },
-      {
-        code_overhead_time => 7.4,
-        errors => 0.00012,
-        participant => "use Log::ger::Output::Screen;",
         samples => 20,
-        time => 13,
-        vs_slowest => 8.3,
+        time => 14,
+        vs_slowest => 7.4,
       },
       {
-        code_overhead_time => 4.4,
-        errors => 0.00015,
+        code_overhead_time => 6,
+        errors => 3.6e-05,
+        participant => "use Log::ger::Output::Screen;",
+        samples => 21,
+        time => 12,
+        vs_slowest => 8.7,
+      },
+      {
+        code_overhead_time => 3.1,
+        errors => 3.1e-05,
         participant => "use Log::ger::Output::Composite;",
         samples => 20,
-        time => 10,
-        vs_slowest => 10,
-      },
-      {
-        code_overhead_time => 3.2,
-        errors => 2.8e-05,
-        participant => "use Log::ger::Plugin::OptAway; use Log::ger;",
-        samples => 22,
-        time => 8.8,
+        time => 9.1,
         vs_slowest => 12,
       },
       {
-        code_overhead_time => 0.9,
-        errors => 3e-05,
+        code_overhead_time => 3,
+        errors => 4.5e-05,
+        participant => "use Log::ger::Plugin::OptAway; use Log::ger;",
+        samples => 21,
+        time => 9,
+        vs_slowest => 12,
+      },
+      {
+        code_overhead_time => 1,
+        errors => 4e-05,
+        participant => "use Log::ger::Like::LogAny;",
+        samples => 20,
+        time => 7,
+        vs_slowest => 15,
+      },
+      {
+        code_overhead_time => 0.6,
+        errors => 2.3e-05,
+        participant => "use Log::ger; Log::ger->get_logger;",
+        samples => 20,
+        time => 6.6,
+        vs_slowest => 16,
+      },
+      {
+        code_overhead_time => 0.6,
+        errors => 3.9e-05,
+        participant => "use Log::ger;",
+        samples => 21,
+        time => 6.6,
+        vs_slowest => 16,
+      },
+      {
+        code_overhead_time => 0.5,
+        errors => 5.1e-05,
         participant => "use Log::ger ();",
         samples => 20,
         time => 6.5,
         vs_slowest => 16,
       },
-      {
-        code_overhead_time => 0.4,
-        errors => 7.4e-05,
-        participant => "use Log::ger; Log::ger->get_logger;",
-        samples => 20,
-        time => 6,
-        vs_slowest => 20,
-      },
-      {
-        code_overhead_time => 0.800000000000001,
-        errors => 1.5e-05,
-        participant => "use Log::ger::Like::LogAny;",
-        samples => 21,
-        time => 6.4,
-        vs_slowest => 16,
-      },
-      {
-        code_overhead_time => 0.7,
-        errors => 3.6e-05,
-        participant => "use Log::ger;",
-        samples => 20,
-        time => 6.3,
-        vs_slowest => 16,
-      },
       {
         code_overhead_time => 0,
-        errors => 3.6e-05,
+        errors => 5.5e-05,
         participant => "perl -e1 (baseline)",
         samples => 20,
-        time => 5.6,
+        time => 6,
         vs_slowest => 18,
       },
     ],
@@ -261,7 +277,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3242.095,
+                                              speed                        => 3271.612,
                                               stepping                     => 7,
                                             },
                                             {
@@ -356,7 +372,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3255.529,
+                                              speed                        => "3250.610",
                                               stepping                     => 7,
                                             },
                                             {
@@ -451,7 +467,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2713.067,
+                                              speed                        => 3278.991,
                                               stepping                     => 7,
                                             },
                                             {
@@ -546,11 +562,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3153.924,
+                                              speed                        => 3255.529,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 15.2736229896545,
+      "func.elapsed_time"              => 19.3380470275879,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                         => 1.041,
@@ -562,17 +578,18 @@ our $results = [
                                             "Log::Dispatch"                       => 2.65,
                                             "Log::Dispatch::Null"                 => 2.65,
                                             "Log::Dispatchouli"                   => 2.015,
-                                            "Log::ger"                            => 0.023,
+                                            "Log::ger"                            => 0.025,
                                             "Log::ger::App"                       => 0.009,
                                             "Log::ger::Layout::Pattern"           => 0.001,
-                                            "Log::ger::Output"                    => 0.023,
+                                            "Log::ger::Output"                    => 0.025,
                                             "Log::Log4perl"                       => 1.49,
                                             "Log::Log4perl::Tiny"                 => "1.4.0",
+                                            "Mojo::Log"                           => undef,
                                             "perl"                                => "v5.26.0",
                                             "Sys::Info"                           => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 19]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 21]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sonya",
@@ -598,13 +615,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Overhead",
-      "func.scenario_module_md5sum"    => "c1109d32fb348d903c9767f1a6d47c34",
-      "func.scenario_module_mtime"     => 1545302243,
-      "func.scenario_module_sha1sum"   => "ee9305bf048c7bd064f0c6444a71822528ba64e0",
-      "func.scenario_module_sha256sum" => "77da734fec62910d35386d2c942b32b2febaa8c5b6f1d3c6534bcda67eb6ceaf",
-      "func.time_end"                  => 1545303649.16709,
+      "func.scenario_module_md5sum"    => "f15bd7fe75e8a6744f821e7aaea031f2",
+      "func.scenario_module_mtime"     => 1545318649,
+      "func.scenario_module_sha1sum"   => "dd2d60453b64bef37c58d3eddcc5374babee3268",
+      "func.scenario_module_sha256sum" => "c49c4f7c28c7ee075825cada044b95f0b0e285155c5016906181f1389561ca83",
+      "func.time_end"                  => 1545319860.72771,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1545303633.89346,
+      "func.time_start"                => 1545319841.38966,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "ms", "ms"],
       "table.fields"                   => [
